@@ -1,7 +1,8 @@
 import asyncio
-from pytr.utils import preview
 from datetime import datetime, timedelta
 
+from pytr.utils import preview
+
 
 class Details:
     def __init__(self, tr, isin):
@@ -13,8 +14,8 @@ class Details:
         await self.tr.stock_details(self.isin)
         await self.tr.news(self.isin)
         # await self.tr.subscribe_news(self.isin)
-        await self.tr.ticker(self.isin, exchange='LSX')
-        await self.tr.performance(self.isin, exchange='LSX')
+        await self.tr.ticker(self.isin, exchange="LSX")
+        await self.tr.performance(self.isin, exchange="LSX")
         await self.tr.instrument_details(self.isin)
         await self.tr.instrument_suitability(self.isin)
 
@@ -26,25 +27,25 @@ class Details:
         while True:
             _subscription_id, subscription, response = await self.tr.recv()
 
-            if subscription['type'] == 'stockDetails':
+            if subscription["type"] == "stockDetails":
                 recv += 1
                 self.stockDetails = response
-            elif subscription['type'] == 'neonNews':
+            elif subscription["type"] == "neonNews":
                 recv += 1
                 self.neonNews = response
-            elif subscription['type'] == 'ticker':
+            elif subscription["type"] == "ticker":
                 recv += 1
                 self.ticker = response
-            elif subscription['type'] == 'performance':
+            elif subscription["type"] == "performance":
                 recv += 1
                 self.performance = response
-            elif subscription['type'] == 'instrument':
+            elif subscription["type"] == "instrument":
                 recv += 1
                 self.instrument = response
-            elif subscription['type'] == 'instrumentSuitability':
+            elif subscription["type"] == "instrumentSuitability":
                 recv += 1
                 self.instrumentSuitability = response
-                print('instrumentSuitability:', response)
+                print("instrumentSuitability:", response)
             else:
                 print(f"unmatched subscription of type '{subscription['type']}':\n{preview(response, num_lines=30)}")
 
@@ -52,30 +53,32 @@ class Details:
                 return
 
     def print_instrument(self):
-        print('Name:', self.instrument['name'])
-        print('ShortName:', self.instrument['shortName'])
-        print('Type:', self.instrument['typeId'])
-        for ex in self.instrument['exchanges']:
+        print("Name:", self.instrument["name"])
+        print("ShortName:", self.instrument["shortName"])
+        print("Type:", self.instrument["typeId"])
+        for ex in self.instrument["exchanges"]:
             print(f"{ex['slug']}: {ex['symbolAtExchange']} {ex['nameAtExchange']}")
 
-        for tag in self.instrument['tags']:
+        for tag in self.instrument["tags"]:
             print(f"{tag['type']}: {tag['name']}")
 
     def stock_details(self):
-        company = self.stockDetails['company']
+        company = self.stockDetails["company"]
         for company_detail in company:
             if company[company_detail] is not None:
-                print(f'{company_detail:15}: {company[company_detail]}')
+                print(f"{company_detail:15}: {company[company_detail]}")
         for detail in self.stockDetails:
-            if detail != 'company' and self.stockDetails[detail] is not None and self.stockDetails[detail] != []:
-                print(f'{detail:15}: {self.stockDetails[detail]}')
+            if detail != "company" and self.stockDetails[detail] is not None and self.stockDetails[detail] != []:
+                print(f"{detail:15}: {self.stockDetails[detail]}")
 
     def news(self, relevant_days=30):
         since = datetime.now() - timedelta(days=relevant_days)
+        if not hasattr(self, "neonNews"):
+            return
         for news in self.neonNews:
-            newsdate = datetime.fromtimestamp(news['createdAt'] / 1000.0)
+            newsdate = datetime.fromtimestamp(news["createdAt"] / 1000.0)
             if newsdate > since:
-                dateiso = newsdate.isoformat(sep=' ', timespec='minutes')
+                dateiso = newsdate.isoformat(sep=" ", timespec="minutes")
                 print(f"{dateiso}: {news['headline']}")
 
     def overview(self):
@@ -84,6 +87,6 @@ class Details:
         self.stock_details()
 
     def get(self):
-        asyncio.get_event_loop().run_until_complete(self.details_loop())
+        asyncio.run(self.details_loop())
 
         self.overview()
